Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6543)

Unified Diff: chrome/common/extensions/api/bluetooth/bluetooth_manifest_handler.h

Issue 145663004: Replace "bluetooth" permission with manifest property. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove unused function. Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/extensions/api/bluetooth/bluetooth_manifest_handler.h
diff --git a/chrome/common/extensions/api/sockets/sockets_manifest_handler.h b/chrome/common/extensions/api/bluetooth/bluetooth_manifest_handler.h
similarity index 59%
copy from chrome/common/extensions/api/sockets/sockets_manifest_handler.h
copy to chrome/common/extensions/api/bluetooth/bluetooth_manifest_handler.h
index 17811564d1eb67bb1d1d62780bc52ec617a4da15..5a7b867b3f759321d342e72ccc8d611ef075a185 100644
--- a/chrome/common/extensions/api/sockets/sockets_manifest_handler.h
+++ b/chrome/common/extensions/api/bluetooth/bluetooth_manifest_handler.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_COMMON_EXTENSIONS_API_SOCKETS_SOCKETS_MANIFEST_HANDLER_H_
-#define CHROME_COMMON_EXTENSIONS_API_SOCKETS_SOCKETS_MANIFEST_HANDLER_H_
+#ifndef CHROME_COMMON_EXTENSIONS_API_BLUETOOTH_BLUETOOTH_MANIFEST_HANDLER_H_
+#define CHROME_COMMON_EXTENSIONS_API_BLUETOOTH_BLUETOOTH_MANIFEST_HANDLER_H_
#include <string>
#include <vector>
@@ -17,25 +17,25 @@ class ManifestPermission;
namespace extensions {
-// Parses the "sockets" manifest key.
-class SocketsManifestHandler : public ManifestHandler {
+// Parses the "bluetooth" manifest key.
+class BluetoothManifestHandler : public ManifestHandler {
public:
- SocketsManifestHandler();
- virtual ~SocketsManifestHandler();
+ BluetoothManifestHandler();
+ virtual ~BluetoothManifestHandler();
// ManifestHandler overrides.
virtual bool Parse(Extension* extension, base::string16* error) OVERRIDE;
virtual ManifestPermission* CreatePermission() OVERRIDE;
virtual ManifestPermission* CreateInitialRequiredPermission(
- const Extension* extension) OVERRIDE;
+ const Extension* extension) OVERRIDE;
private:
// ManifestHandler overrides.
virtual const std::vector<std::string> Keys() const OVERRIDE;
- DISALLOW_COPY_AND_ASSIGN(SocketsManifestHandler);
+ DISALLOW_COPY_AND_ASSIGN(BluetoothManifestHandler);
};
} // namespace extensions
-#endif // CHROME_COMMON_EXTENSIONS_API_SOCKETS_SOCKETS_MANIFEST_HANDLER_H_
+#endif // CHROME_COMMON_EXTENSIONS_API_BLUETOOTH_BLUETOOTH_MANIFEST_HANDLER_H_

Powered by Google App Engine
This is Rietveld 408576698